@@ -13,14 +13,16 @@
 //!
 //! # Examples
 //!
-//! ## List all public items of a crate
+//! The two main use cases are listing public items, and diffing public items.
+//!
+//! ## List all public items of a crate (the public API)
 //! ```
 #![doc = include_str!("../examples/list_public_items.rs")]
 //! ```
 //!
 //! ## Diff two versions of a public API
 //! ```
-#![doc = include_str!("../examples/public_api_diff.rs")]
+#![doc = include_str!("../examples/diff_public_items.rs")]
 //! ```
 //!
 //! The most comprehensive example code on how to use the library can be found
@@ -111,8 +113,8 @@ impl Default for Options {
 /// [`PublicItem`] is one public item of the crate, i.e. part of the crate's
 /// public API.
 ///
-/// There exists a convenient `cargo public-items` subcommand wrapper for this
-/// function found at <https://github.com/Enselic/cargo-public-items> that
+/// There exists a convenient `cargo public-api` subcommand wrapper for this
+/// function found at <https://github.com/Enselic/cargo-public-api> that
 /// builds the rustdoc JSON for you and then invokes this function. If you don't
 /// want to use that wrapper, use
 /// ```bash
